@@ -11,7 +11,7 @@ use List::MoreUtils;
 use Template::Plugin::Procedural;
 use vars qw(@ISA $VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 @ISA     = qw(Template::Plugin::Procedural);
 
 =head1 NAME
@@ -80,6 +80,30 @@ sub none(&\@) { List::MoreUtils::none( \&{ $_[0] }, @{ $_[1] } ); }
 
 sub notall(&\@) { List::MoreUtils::notall( \&{ $_[0] }, @{ $_[1] } ); }
 
+=head2 any_u BLOCK LIST
+
+=cut
+
+sub any_u(&\@) { List::MoreUtils::any_u( \&{ $_[0] }, @{ $_[1] } ); }
+
+=head2 all_u BLOCK LIST
+
+=cut
+
+sub all_u(&\@) { List::MoreUtils::all_u( \&{ $_[0] }, @{ $_[1] } ); }
+
+=head2 none_u BLOCK LIST
+
+=cut
+
+sub none_u(&\@) { List::MoreUtils::none_u( \&{ $_[0] }, @{ $_[1] } ); }
+
+=head2 notall_u BLOCK LIST
+
+=cut
+
+sub notall_u(&\@) { List::MoreUtils::notall_u( \&{ $_[0] }, @{ $_[1] } ); }
+
 =head2 true BLOCK LIST
 
 =cut
@@ -110,6 +134,69 @@ sub firstidx(&\@) { List::MoreUtils::firstidx( \&{ $_[0] }, @{ $_[1] } ); }
 sub lastidx(&\@) { List::MoreUtils::lastidx( \&{ $_[0] }, @{ $_[1] } ); }
 *last_index = *{'lastidx'}{CODE};
 
+=head2 onlyidx BLOCK LIST
+
+=head2 only_index BLOCK LIST
+
+=cut
+
+sub onlyidx(&\@) { List::MoreUtils::onlyidx( \&{ $_[0] }, @{ $_[1] } ); }
+*only_index = *{'onlyidx'}{CODE};
+
+=head2 firstres BLOCK LIST
+
+=head2 first_result BLOCK LIST
+
+=cut
+
+sub firstres(&\@) { List::MoreUtils::firstres( \&{ $_[0] }, @{ $_[1] } ); }
+*first_result = *{'firstres'}{CODE};
+
+=head2 lastres BLOCK LIST
+
+=head2 last_result BLOCK LIST
+
+=cut
+
+sub lastres(&\@) { List::MoreUtils::lastres( \&{ $_[0] }, @{ $_[1] } ); }
+*last_result = *{'lastres'}{CODE};
+
+=head2 onlyres BLOCK LIST
+
+=head2 only_result BLOCK LIST
+
+=cut
+
+sub onlyres(&\@) { List::MoreUtils::onlyres( \&{ $_[0] }, @{ $_[1] } ); }
+*only_result = *{'onlyres'}{CODE};
+
+=head2 firstval BLOCK LIST
+
+=head2 first_value BLOCK LIST
+
+=cut
+
+sub firstval(&\@) { List::MoreUtils::firstval( \&{ $_[0] }, @{ $_[1] } ); }
+*first_value = *{'firstval'}{CODE};
+
+=head2 lastval BLOCK LIST
+
+=head2 last_value BLOCK LIST
+
+=cut
+
+sub lastval(&\@) { List::MoreUtils::lastval( \&{ $_[0] }, @{ $_[1] } ); }
+*last_value = *{'lastval'}{CODE};
+
+=head2 onlyval BLOCK LIST
+
+=head2 only_value BLOCK LIST
+
+=cut
+
+sub onlyval(&\@) { List::MoreUtils::onlyval( \&{ $_[0] }, @{ $_[1] } ); }
+*only_value = *{'onlyval'}{CODE};
+
 =head2 insert_after BLOCK VALUE LIST
 
 =cut
@@ -159,24 +246,6 @@ sub before_incl(&\@) { List::MoreUtils::before_incl( \&{ $_[0] }, @{ $_[1] } );
 
 sub indexes(&\@) { List::MoreUtils::indexes( \&{ $_[0] }, @{ $_[1] } ); }
 
-=head2 firstval BLOCK LIST
-
-=head2 first_value BLOCK LIST
-
-=cut
-
-sub firstval(&\@) { List::MoreUtils::firstval( \&{ $_[0] }, @{ $_[1] } ); }
-*first_value = *{'firstval'}{CODE};
-
-=head2 lastval BLOCK LIST
-
-=head2 last_value BLOCK LIST
-
-=cut
-
-sub lastval(&\@) { List::MoreUtils::lastval( \&{ $_[0] }, @{ $_[1] } ); }
-*last_value = *{'lastval'}{CODE};
-
 =head2 pairwise BLOCK LIST LIST
 
 Unlike the original C<pairwise>, both variables are given through C<@_>.
@@ -199,9 +268,18 @@ sub minmax(\@) { List::MoreUtils::minmax( @{ $_[0] } ); }
 
 =head2 uniq LIST
 
+=head2 distinct LIST
+
 =cut
 
 sub uniq(\@) { List::MoreUtils::uniq( @{ $_[0] } ); }
+*distinct = *{'uniq'}{CODE};
+
+=head2 singleton LIST
+
+=cut
+
+sub singleton(\@) { List::MoreUtils::singleton( @{ $_[0] } ); }
 
 =head2 mesh
 
@@ -220,33 +298,26 @@ sub part(&\@) { List::MoreUtils::part( \&{ $_[0] }, @{ $_[1] } ) }
 
 =head2 bsearch BLOCK LIST
 
-This function is available only when List::MoreUtils 0.23 or newer is used.
+=cut
 
-Unlike the original C<bsearch>, the value to compare with is passed in
-C<$_[0]>.  Template::Toolkit uses eval to evaluate the perl code declared
-there and don't pass C<$_> (which sounds reasonable to me).
+sub bsearch(&\@)
+{
+    my $user_fn = $_[0];
+    List::MoreUtils::bsearch( sub { $user_fn->($_) }, @{ $_[1] } );
+}
+
+=head2 bsearchidx BLOCK LIST
+
+=head2 bsearch_index BLOCK LIST
 
 =cut
 
-if ( defined( *{'List::MoreUtils::bsearch'}{CODE} ) )
+sub bsearchidx(&\@)
 {
-    eval <<'EOBS';
-sub bsearch(&\@)
-{
-    my $userfn = $_[0];
-    List::MoreUtils::bsearch( sub { &{$userfn}( $_ ); }, @{$_[1]} );
+    my $user_fn = $_[0];
+    List::MoreUtils::bsearchidx( sub { $user_fn->($_) }, @{ $_[1] } );
 }
-EOBS
-}
-
-=head1 INSTALL
-
-To install this module, use
-
-  perl Build.PL
-  ./Build
-  ./Build test
-  ./Build install
+*bsearch_index = *{'bsearchidx'}{CODE};
 
 =head1 LIMITATION
 
@@ -254,30 +325,54 @@ Except the typical limitations known from perl functions embedded in
 L<Template::Toolkit>, the only limitation I currently miss is being
 able to use TT2 defined macros as callback.
 
+=head1 BUGS
+
+Please report any bugs or feature requests to
+C<bug-Template-Plugin-ListMoreUtils at rt.cpan.org>, or through the web interface at
+L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Template-Plugin-ListMoreUtils>.
+I will be notified, and then you'll automatically be notified of progress
+on your bug as I make changes.
+
 =head1 SUPPORT
 
-Free support can be requested via regular CPAN bug-tracking system. There is
-no guaranteed reaction time or solution time. It depends on business load.
-That doesn't mean that ticket via rt aren't handles as soon as possible, that
-means that soon depends on how much I have to do.
+You can find documentation for this module with the perldoc command.
 
-Business and commercial support should be aquired via preferred freelancer
+    perldoc Template::Plugin::ListMoreUtils
+
+You can also look for information at:
+
+=over 4
+
+=item * RT: CPAN's request tracker
+
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Template-Plugin-ListMoreUtils>
+
+=item * AnnoCPAN: Annotated CPAN documentation
+
+L<http://annocpan.org/dist/Template-Plugin-ListMoreUtils>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/Template-Plugin-ListMoreUtils>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/Template-Plugin-ListMoreUtils/>
+
+=back
+
+Business and commercial support should be acquired via preferred freelancer
 agencies.
 
-=head1 AUTHOR
+=head1 LICENSE AND COPYRIGHT
 
-    Jens Rehsack
-    CPAN ID: REHSACK
-    rehsack@cpan.org
-    http://search.cpan.org/~rehsack/
+Copyright 2009-2015 Jens Rehsack.
 
-=head1 COPYRIGHT
+This program is free software; you can redistribute it and/or modify it
+under the terms of either: the GNU General Public License as published
+by the Free Software Foundation; or the Artistic License.
 
-This program is free software; you can redistribute
-it and/or modify it under the same terms as Perl itself.
-
-The full text of the license can be found in the
-LICENSE file included with this module.
+See http://dev.perl.org/licenses/ for more information.
 
 =head1 SEE ALSO
 
